@@ -1,6 +1,6 @@
 #!/usr/bin/env python2.7
 #from Tophat.tophat import TophatMain
-from Networking.protocolhandler import ProtocolHandler
+from TopHat_Platform.Networking.protocolhandler import ProtocolHandler
 from optparse import OptionParser
 from sys import exit, stderr,stdin,stdout
 import sys
